If you’re using the service, you’re probably looking for KinesisVideoMediaClient and KinesisVideoMedia.
Structs
- GetMedia
Input - GetMedia
Output - Kinesis
Video Media Client - A client for the Kinesis Video Media API.
- Start
Selector Identifies the chunk on the Kinesis video stream where you want the
GetMediaAPI to start returning media data. You have the following options to identify the starting chunk:-
Choose the latest (or oldest) chunk.
-
Identify a specific chunk. You can identify a specific chunk either by providing a fragment number or timestamp (server or producer).
-
Each chunk's metadata includes a continuation token as a Matroska (MKV) tag (
AWSKINESISVIDEOCONTINUATION_TOKEN). If your previousGetMediarequest terminated, you can use this tag value in your nextGetMediarequest. The API then starts returning chunks starting where the last API ended.
-
Enums
- GetMedia
Error - Errors returned by GetMedia
Traits
- Kinesis
Video Media - Trait representing the capabilities of the Kinesis Video Media API. Kinesis Video Media clients implement this trait.